% P23Esthypot.m Stat sig proc
% COPYRIGHT:  Aprend Technology, 2011. All rights reserved.
 
%% 3D Plot of logI vs A
   % function to compute mean number of transmitted photons 
flambda = @(A,mus,specnum) sum(specnum(:).*exp(-mus*A')); % mean photons per measurement
   % step wedge thicknesses, gm/cm^2
nsteps = 40;
fprintf('\n\n nsteps %d\n',nsteps);  
t1s = linspace(0,5,nsteps); % aluminum thicknesses 
t2s =  linspace(0,30,nsteps); % plastic thicknesses
   % create calibration step wedge thickness combinations
ts = [];
for t1 = t1s
  for t2 = t2s
    ts(end+1,:) = [t1 t2];
  end % for t2 = t2s
end % for t1 = t1s
   % the spectrum and attenuation coefficients
tube_voltage = 80; % keV  
[specnum,xray_energies,specdat] = XrayTubeSpectrumTasmip(tube_voltage,'number_spectrum','clipzeros');
mus = [xraymu('Al',xray_energies) xraymu('C5O2H8',xray_energies)]; % aluminum and acrylic plastic
   % the mean value of transmitted number of photons
nthick = size(ts,1);
Is = zeros(nthick,1);
for k = 1:nthick 
   Is(k) = flambda(ts(k,:),mus,specnum);
end

%% do 3D plot
fh = figure;
[xs,ys] = meshgrid(t1s,t2s);
hs = surf(xs,ys,reshape(-log(Is/Is(1)),nsteps,nsteps));
colormap(gray)
fontsize = 14;
linewid = 1.5;
set(hs,'EdgeColor',0.5*[1 1 1])
ht1 = text(2,-3,-1.7,'A_1 (cm)','fontsize',fontsize);
set(ht1,'rotation',-15)
ht2 = text(6.5,12,-1.7,'A_2 (cm)','fontsize',fontsize);
set(ht2,'rotation',22);
ht3 = text(-0.8,-0.8,3.5,'-log(I/I_0)','fontsize',12);
set(ht3,'rotation',90);
set(gca,'CameraPosition',[33.8862 -142.15 61.0708]);
set(gca,'fontsize',fontsize,'linewidth',linewid)
set(fh,'position',[250 400 675 500])


%% export the figure as png and eps
dirname = 'E:\Projects\Blog\Posts\P23EstHypot/';
figno = sprintf('-f%d',fh);
fname = 'LogIvsA';
   % export as eps
exportfig(fh,[dirname fname '.eps'],'width',5,'LockAxes',0,'color','cmyk');
set(fh,'papertype','usletter')
print(figno,'-dpng','-cmyk','-r100',[dirname fname '.png']) % resolution 100 dpi
